@@ -1,12 +1,15 @@
 #' @rdname print.effectsize_table
 #' @export
+#' @importFrom insight check_if_installed
 plot.effectsize_table <- function(x, ...) {
-  check_if_installed("see", reason = "for plotting")
+  insight::check_if_installed("see", reason = "for plotting")
   NextMethod()
 }
 
+#' @rdname print.effectsize_table
 #' @export
+#' @importFrom insight check_if_installed
 plot.equivalence_test_effectsize <- function(x, ...) {
-  check_if_installed("see", reason = "for plotting")
+  insight::check_if_installed("see", reason = "for plotting")
   NextMethod()
 }
