@@ -1,3 +1,21 @@
+#' @importFrom bayestestR equivalence_test
+#' @export
+bayestestR::equivalence_test
+
+#' @export
+#' @importFrom datawizard standardize
+datawizard::standardize
+
+
+
+
+
+## TODO: removed the following from see / modelbased --------------------
+
+#' @export
+#' @importFrom datawizard ranktransform
+datawizard::ranktransform
+
 #' @export
 #' @importFrom datawizard adjust
 datawizard::adjust
@@ -10,14 +28,6 @@ datawizard::change_scale
 #' @importFrom datawizard normalize
 datawizard::normalize
 
-#' @export
-#' @importFrom datawizard ranktransform
-datawizard::ranktransform
-
-#' @export
-#' @importFrom datawizard standardize
-datawizard::standardize
-
 #' @export
 #' @importFrom datawizard unstandardize
-datawizard::unstandardize
+datawizard::unstandardize
\ No newline at end of file
